=====================================
Roadmap & NumPy Enhancement Proposals
=====================================

This page provides an overview of development priorities for NumPy.
Specifically, it contains a roadmap with a higher-level overview, as
well as NumPy Enhancement Proposals (NEPs)—suggested changes
to the library—in various stages of discussion or completion (see `NEP
0 <nep-0000>`__).

Roadmap
-------
.. toctree::
   :maxdepth: 1

   The Scope of NumPy <scope>
   Current roadmap <roadmap>
   Wish list <https://github.com/numpy/numpy/issues?q=is%3Aopen+is%3Aissue+label%3A%2223+-+Wish+List%22>

NumPy Enhancement Proposals (NEPs)
----------------------------------

.. toctree::
   :maxdepth: 2

   meta
   provisional
   accepted
   open
   finished
   deferred
   rejected
